@@ -15,7 +15,7 @@ LineStripSet::LineStripSet(Material& in_material, int in_nvertices, double* in_v
   if (material.line_antialias) blended = true;
 }
 
-void LineStripSet::drawElement(RenderContext* renderContext, int index)
+void LineStripSet::drawPrimitive(RenderContext* renderContext, int index)
 {
   if (index < nvertices-1) 
     glDrawArrays(type, index*nverticesperelement, 2*nverticesperelement);
